==> jc-1.4.0.tar.gz: java/security/KeyFactorySpi.h <==
// public abstract class java.security.KeyFactorySpi

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 5208a7db73e048db java_security_KeyFactorySpi

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_security_KeyFactorySpi_H_
#define _JC_java_security_KeyFactorySpi_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_security_Key$object;
struct _jc_java_security_PrivateKey$object;
struct _jc_java_security_PublicKey$object;
struct _jc_java_security_spec_KeySpec$object;

// Typedefs
typedef struct _jc_java_security_KeyFactorySpi$sub_refs	_jc_java_security_KeyFactorySpi$sub_refs;
typedef struct _jc_java_security_KeyFactorySpi$sub_nonrefs	_jc_java_security_KeyFactorySpi$sub_nonrefs;
typedef struct _jc_java_security_KeyFactorySpi$refs	_jc_java_security_KeyFactorySpi$refs;
typedef struct _jc_java_security_KeyFactorySpi$nonrefs	_jc_java_security_KeyFactorySpi$nonrefs;
typedef struct _jc_java_security_KeyFactorySpi$object	_jc_java_security_KeyFactorySpi$object;

typedef const struct _jc_java_security_KeyFactorySpi$vmethods	_jc_java_security_KeyFactorySpi$vmethods;
typedef const struct _jc_java_security_KeyFactorySpi$vtable	_jc_java_security_KeyFactorySpi$vtable;
typedef const struct _jc_java_security_KeyFactorySpi$vtype	_jc_java_security_KeyFactorySpi$vtype;

// Constructors
extern void _jc_java_security_KeyFactorySpi$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_security_KeyFactorySpi$object *);

// Virtual methods
extern struct _jc_object *_jc_java_security_KeyFactorySpi$method$engineGeneratePrivate$5f899f5d07075f18(_jc_env *, struct _jc_java_security_KeyFactorySpi$object *, struct _jc_object *);
extern struct _jc_object *_jc_java_security_KeyFactorySpi$method$engineGeneratePublic$7ad176effa9fa186(_jc_env *, struct _jc_java_security_KeyFactorySpi$object *, struct _jc_object *);
extern struct _jc_object *_jc_java_security_KeyFactorySpi$method$engineGetKeySpec$8e11b093f262567f(_jc_env *, struct _jc_java_security_KeyFactorySpi$object *, struct _jc_object *, struct _jc_java_lang_Class$object *);
extern struct _jc_object *_jc_java_security_KeyFactorySpi$method$engineTranslateKey$486445c69e67c534(_jc_env *, struct _jc_java_security_KeyFactorySpi$object *, struct _jc_object *);

// Virtual method descriptors
extern _jc_method _jc_java_security_KeyFactorySpi$method_info$engineGeneratePrivate$5f899f5d07075f18;
extern _jc_method _jc_java_security_KeyFactorySpi$method_info$engineGeneratePublic$7ad176effa9fa186;
extern _jc_method _jc_java_security_KeyFactorySpi$method_info$engineGetKeySpec$8e11b093f262567f;
extern _jc_method _jc_java_security_KeyFactorySpi$method_info$engineTranslateKey$486445c69e67c534;

// Virtual methods structure
struct _jc_java_security_KeyFactorySpi$vmethods {
	struct _jc_object	*(*engineGeneratePrivate$5f899f5d07075f18)(_jc_env *, struct _jc_java_security_KeyFactorySpi$object *, struct _jc_object *);
	struct _jc_object	*(*engineGeneratePublic$7ad176effa9fa186)(_jc_env *, struct _jc_java_security_KeyFactorySpi$object *, struct _jc_object *);
	struct _jc_object	*(*engineGetKeySpec$8e11b093f262567f)(_jc_env *, struct _jc_java_security_KeyFactorySpi$object *, struct _jc_object *, struct _jc_java_lang_Class$object *);
	struct _jc_object	*(*engineTranslateKey$486445c69e67c534)(_jc_env *, struct _jc_java_security_KeyFactorySpi$object *, struct _jc_object *);
};

// Vtable
struct _jc_java_security_KeyFactorySpi$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_security_KeyFactorySpi$vmethods	java_security_KeyFactorySpi;
};

// Vtype
struct _jc_java_security_KeyFactorySpi$vtype {
	_jc_type			type;
	_jc_java_security_KeyFactorySpi$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_security_KeyFactorySpi$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_security_KeyFactorySpi$refs {
    _jc_java_security_KeyFactorySpi$sub_refs	java_security_KeyFactorySpi;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_security_KeyFactorySpi$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_security_KeyFactorySpi$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_security_KeyFactorySpi$sub_nonrefs	java_security_KeyFactorySpi;
};

// Object instance structure
struct _jc_java_security_KeyFactorySpi$object {
	_jc_java_security_KeyFactorySpi$refs	refs[0];
	_jc_word		lockword;
	_jc_java_security_KeyFactorySpi$vtype	*vtype;
	_jc_java_security_KeyFactorySpi$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_security_KeyFactorySpi$vtype _jc_java_security_KeyFactorySpi$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_security_KeyFactorySpi, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_security_KeyFactorySpi$class_object;

#endif	/* _JC_java_security_KeyFactorySpi_H_ */

==> jc-1.4.6.tar.gz: java/security/KeyFactorySpi.h <==
// public abstract class java.security.KeyFactorySpi

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 5208a7db73e048db java_security_KeyFactorySpi

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_security_KeyFactorySpi_H_
#define _JC_java_security_KeyFactorySpi_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_security_Key$object;
struct _jc_java_security_PrivateKey$object;
struct _jc_java_security_PublicKey$object;
struct _jc_java_security_spec_KeySpec$object;

// Typedefs
typedef struct _jc_java_security_KeyFactorySpi$sub_refs	_jc_java_security_KeyFactorySpi$sub_refs;
typedef struct _jc_java_security_KeyFactorySpi$sub_nonrefs	_jc_java_security_KeyFactorySpi$sub_nonrefs;
typedef struct _jc_java_security_KeyFactorySpi$refs	_jc_java_security_KeyFactorySpi$refs;
typedef struct _jc_java_security_KeyFactorySpi$nonrefs	_jc_java_security_KeyFactorySpi$nonrefs;
typedef struct _jc_java_security_KeyFactorySpi$object	_jc_java_security_KeyFactorySpi$object;

typedef const struct _jc_java_security_KeyFactorySpi$vmethods	_jc_java_security_KeyFactorySpi$vmethods;
typedef const struct _jc_java_security_KeyFactorySpi$vtable	_jc_java_security_KeyFactorySpi$vtable;
typedef const struct _jc_java_security_KeyFactorySpi$vtype	_jc_java_security_KeyFactorySpi$vtype;

// Constructors
extern void _jc_java_security_KeyFactorySpi$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_security_KeyFactorySpi$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_object *_jc_java_security_KeyFactorySpi$method$engineGeneratePrivate$5f899f5d07075f18(_jc_env *, struct _jc_java_security_KeyFactorySpi$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_java_security_KeyFactorySpi$method$engineGeneratePublic$7ad176effa9fa186(_jc_env *, struct _jc_java_security_KeyFactorySpi$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_java_security_KeyFactorySpi$method$engineGetKeySpec$8e11b093f262567f(_jc_env *, struct _jc_java_security_KeyFactorySpi$object *, struct _jc_object *, struct _jc_java_lang_Class$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_java_security_KeyFactorySpi$method$engineTranslateKey$486445c69e67c534(_jc_env *, struct _jc_java_security_KeyFactorySpi$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_security_KeyFactorySpi$method_info$engineGeneratePrivate$5f899f5d07075f18;
extern _jc_method _jc_java_security_KeyFactorySpi$method_info$engineGeneratePublic$7ad176effa9fa186;
extern _jc_method _jc_java_security_KeyFactorySpi$method_info$engineGetKeySpec$8e11b093f262567f;
extern _jc_method _jc_java_security_KeyFactorySpi$method_info$engineTranslateKey$486445c69e67c534;

// Virtual methods structure
struct _jc_java_security_KeyFactorySpi$vmethods {
	struct _jc_object	*(*engineGeneratePrivate$5f899f5d07075f18)(_jc_env *, struct _jc_java_security_KeyFactorySpi$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*engineGeneratePublic$7ad176effa9fa186)(_jc_env *, struct _jc_java_security_KeyFactorySpi$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*engineGetKeySpec$8e11b093f262567f)(_jc_env *, struct _jc_java_security_KeyFactorySpi$object *, struct _jc_object *, struct _jc_java_lang_Class$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*engineTranslateKey$486445c69e67c534)(_jc_env *, struct _jc_java_security_KeyFactorySpi$object *, struct _jc_object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_security_KeyFactorySpi$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_security_KeyFactorySpi$vmethods	java_security_KeyFactorySpi;
};

// Vtype
struct _jc_java_security_KeyFactorySpi$vtype {
	_jc_type			type;
	_jc_java_security_KeyFactorySpi$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_security_KeyFactorySpi$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_security_KeyFactorySpi$refs {
    _jc_java_security_KeyFactorySpi$sub_refs	java_security_KeyFactorySpi;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_security_KeyFactorySpi$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_security_KeyFactorySpi$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_security_KeyFactorySpi$sub_nonrefs	java_security_KeyFactorySpi;
};

// Object instance structure
struct _jc_java_security_KeyFactorySpi$object {
	_jc_java_security_KeyFactorySpi$refs	refs[0];
	_jc_word		lockword;
	_jc_java_security_KeyFactorySpi$vtype	*vtype;
	_jc_java_security_KeyFactorySpi$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_security_KeyFactorySpi$vtype _jc_java_security_KeyFactorySpi$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_security_KeyFactorySpi, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_security_KeyFactorySpi$class_object;

#endif	/* _JC_java_security_KeyFactorySpi_H_ */
